pub enum EngineError {
NoInstructionsRemain,
RuntimeLimit(RuntimeLimitError),
Panic(PanicError),
}Expand description
Engine error that cannot be caught from within ECMAScript code.
Variants
NoInstructionsRemain
Error thrown when no instructions remain. Only used in a fuzzing context.
RuntimeLimit(RuntimeLimitError)
Error thrown when a runtime limit is exceeded.
Panic(PanicError)
Error thrown when an internal panic condition is encountered.