pub enum ErasedEngineError {
NoInstructionsRemain,
RuntimeLimit(RuntimeLimitError),
Panic(ErasedPanicError),
}Expand description
Erased version of EngineError.
This is mainly useful to convert an EngineError into an ErasedEngineError that also
implements Send + Sync, which makes it compatible with error reporting tools
such as anyhow, eyre or miette.
Generally, the conversion from EngineError to ErasedEngineError is unidirectional,
since any JsError that is a JsValue is converted to its string representation
instead. This will lose information if that value was an object, a symbol or a big int.
Variants
NoInstructionsRemain
Error thrown when no instructions remain. Only used in a fuzzing context.
RuntimeLimit(RuntimeLimitError)
Error thrown when a runtime limit is exceeded.
Panic(ErasedPanicError)
Error thrown when an internal panic condition is encountered.