#[non_exhaustive]pub enum JsNativeErrorKind {
Aggregate(Vec<JsError>),
Error,
Eval,
Range,
Reference,
Syntax,
Type,
Uri,
}Expand description
The list of possible error types a JsNativeError can be.
More information:
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Aggregate(Vec<JsError>)
A collection of errors wrapped in a single error.
More information:
Error
A generic error. Commonly used as the base for custom exceptions.
More information:
Eval
An error related to the global function eval().
More information:
Range
An error thrown when a value is outside its valid range.
More information:
Reference
An error representing an invalid de-reference of a variable.
More information:
Syntax
An error representing an invalid syntax in the Javascript language.
More information:
Type
An error thrown when a variable or argument is not of a valid type.
More information:
Uri
An error thrown when the encodeURI() and decodeURI() functions receive
invalid parameters.
More information: