pub struct JsErasedError { /* private fields */ }Expand description
Erased version of JsError.
This is mainly useful to convert a JsError into an Error that also
implements Send + Sync, which makes it compatible with error reporting tools
such as anyhow, eyre or miette.
Generally, the conversion from JsError to JsErasedError is unidirectional,
since any JsError that is a JsValue is converted to its string representation
instead. This will lose information if that value was an object, a symbol or a big int.
Implementations
Sourceimpl JsErasedError
impl JsErasedError
Sourcepub fn as_opaque(&self) -> Option<&str>
pub fn as_opaque(&self) -> Option<&str>
Gets the inner str if the error is an opaque error,
or None otherwise.
Sourcepub const fn as_native(&self) -> Option<&JsErasedNativeError>
pub const fn as_native(&self) -> Option<&JsErasedNativeError>
Gets the inner JsErasedNativeError if the error is a native
error, or None otherwise.
Sourcepub const fn as_engine(&self) -> Option<&ErasedEngineError>
pub const fn as_engine(&self) -> Option<&ErasedEngineError>
Gets the inner ErasedEngineError if the error is an engine
error, or None otherwise.