pub struct JsNativeError { /* private fields */ }Expand description
Native representation of an ideal Error object from Javascript.
This representation is more space efficient than its JsObject equivalent,
since it doesn’t need to create a whole new JsObject to be instantiated.
Prefer using this over JsError when you don’t need to throw
plain JsValues as errors, or when you need to inspect the error type
of a JsError.
Examples
let native_error = JsNativeError::uri().with_message("cannot decode uri");
match native_error.kind() {
JsNativeErrorKind::Uri => { /* handle URI error*/ }
_ => unreachable!(),
}
assert_eq!(native_error.message(), "cannot decode uri");Implementations
Sourceimpl JsNativeError
impl JsNativeError
Sourcepub const fn kind(&self) -> &JsNativeErrorKind
pub const fn kind(&self) -> &JsNativeErrorKind
Returns the kind of this native error.
Sourcepub const fn aggregate(errors: Vec<JsError>) -> Self
pub const fn aggregate(errors: Vec<JsError>) -> Self
Creates a new JsNativeError of kind AggregateError from a list of JsErrors, with
empty message and undefined cause.
Examples
let inner_errors = vec![
JsNativeError::typ().into(),
JsNativeError::syntax().into()
];
let error = JsNativeError::aggregate(inner_errors);
assert!(matches!(
error.kind(),
JsNativeErrorKind::Aggregate(errors) if errors.len() == 2
));Sourcepub const fn is_aggregate(&self) -> bool
pub const fn is_aggregate(&self) -> bool
Check if it’s a JsNativeErrorKind::Aggregate.
Sourcepub const fn error() -> Self
pub const fn error() -> Self
Creates a new JsNativeError of kind Error, with empty message and undefined cause.
Examples
let error = JsNativeError::error();
assert!(matches!(error.kind(), JsNativeErrorKind::Error));Sourcepub const fn is_error(&self) -> bool
pub const fn is_error(&self) -> bool
Check if it’s a JsNativeErrorKind::Error.
Sourcepub const fn eval() -> Self
pub const fn eval() -> Self
Creates a new JsNativeError of kind EvalError, with empty message and undefined cause.
Examples
let error = JsNativeError::eval();
assert!(matches!(error.kind(), JsNativeErrorKind::Eval));Sourcepub const fn is_eval(&self) -> bool
pub const fn is_eval(&self) -> bool
Check if it’s a JsNativeErrorKind::Eval.
Sourcepub const fn range() -> Self
pub const fn range() -> Self
Creates a new JsNativeError of kind RangeError, with empty message and undefined cause.
Examples
let error = JsNativeError::range();
assert!(matches!(error.kind(), JsNativeErrorKind::Range));Sourcepub const fn is_range(&self) -> bool
pub const fn is_range(&self) -> bool
Check if it’s a JsNativeErrorKind::Range.
Sourcepub const fn reference() -> Self
pub const fn reference() -> Self
Creates a new JsNativeError of kind ReferenceError, with empty message and undefined cause.
Examples
let error = JsNativeError::reference();
assert!(matches!(error.kind(), JsNativeErrorKind::Reference));Sourcepub const fn is_reference(&self) -> bool
pub const fn is_reference(&self) -> bool
Check if it’s a JsNativeErrorKind::Reference.
Sourcepub const fn syntax() -> Self
pub const fn syntax() -> Self
Creates a new JsNativeError of kind SyntaxError, with empty message and undefined cause.
Examples
let error = JsNativeError::syntax();
assert!(matches!(error.kind(), JsNativeErrorKind::Syntax));Sourcepub const fn is_syntax(&self) -> bool
pub const fn is_syntax(&self) -> bool
Check if it’s a JsNativeErrorKind::Syntax.
Sourcepub const fn typ() -> Self
pub const fn typ() -> Self
Creates a new JsNativeError of kind TypeError, with empty message and undefined cause.
Examples
let error = JsNativeError::typ();
assert!(matches!(error.kind(), JsNativeErrorKind::Type));Sourcepub const fn is_type(&self) -> bool
pub const fn is_type(&self) -> bool
Check if it’s a JsNativeErrorKind::Type.
Sourcepub const fn uri() -> Self
pub const fn uri() -> Self
Creates a new JsNativeError of kind UriError, with empty message and undefined cause.
Examples
let error = JsNativeError::uri();
assert!(matches!(error.kind(), JsNativeErrorKind::Uri));Sourcepub const fn is_uri(&self) -> bool
pub const fn is_uri(&self) -> bool
Check if it’s a JsNativeErrorKind::Uri.
Sourcepub fn with_message<S>(self, message: S) -> Self
pub fn with_message<S>(self, message: S) -> Self
Sets the message of this error.
Examples
let error = JsNativeError::range().with_message("number too large");
assert_eq!(error.message(), "number too large");Sourcepub fn with_cause<V>(self, cause: V) -> Self
pub fn with_cause<V>(self, cause: V) -> Self
Sourcepub fn message(&self) -> &str
pub fn message(&self) -> &str
Gets the message of this error.
This is equivalent to the NativeError.prototype.message
property.
Examples
let error = JsNativeError::range().with_message("number too large");
assert_eq!(error.message(), "number too large");Sourcepub fn cause(&self) -> Option<&JsError>
pub fn cause(&self) -> Option<&JsError>
Gets the cause of this error.
This is equivalent to the NativeError.prototype.cause
property.
Examples
let cause = JsNativeError::syntax();
let error = JsNativeError::error().with_cause(cause);
assert!(error.cause().unwrap().as_native().is_some());Sourcepub fn into_opaque(self, context: &mut Context) -> JsObject
pub fn into_opaque(self, context: &mut Context) -> JsObject
Converts this native error to its opaque representation as a JsObject.
Examples
let context = &mut Context::default();
let error = JsNativeError::error().with_message("error!");
let error_obj = error.into_opaque(context);
assert!(error_obj.is::<Error>());
assert_eq!(
error_obj.get(js_string!("message"), context).unwrap(),
js_string!("error!").into()
)Trait Implementations
Sourceimpl Clone for JsNativeError
impl Clone for JsNativeError
Sourcefn clone(&self) -> JsNativeError
fn clone(&self) -> JsNativeError
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for JsNativeError
impl Debug for JsNativeError
Sourceimpl Display for JsNativeError
impl Display for JsNativeError
Sourceimpl Error for JsNativeError
impl Error for JsNativeError
Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
use the Display impl or to_string()
Sourceimpl From<Error> for JsNativeError
impl From<Error> for JsNativeError
Sourceimpl From<IcuError> for JsNativeError
impl From<IcuError> for JsNativeError
Sourceimpl From<JsNativeError> for JsError
impl From<JsNativeError> for JsError
Sourcefn from(error: JsNativeError) -> Self
fn from(error: JsNativeError) -> Self
Sourceimpl From<TemporalError> for JsNativeError
impl From<TemporalError> for JsNativeError
Sourcefn from(value: TemporalError) -> Self
fn from(value: TemporalError) -> Self
Sourceimpl PartialEq for JsNativeError
impl PartialEq for JsNativeError
Sourceimpl Trace for JsNativeError
impl Trace for JsNativeError
Sourceunsafe fn trace_non_roots(&self)
unsafe fn trace_non_roots(&self)
Sourcefn run_finalizer(&self)
fn run_finalizer(&self)
Finalize::finalize on this object and all
contained subobjects.impl Eq for JsNativeError
impl StructuralPartialEq for JsNativeError