Job

Enum Job 

#[non_exhaustive]
pub enum Job { PromiseJob(PromiseJob), AsyncJob(NativeAsyncJob), TimeoutJob(TimeoutJob), IntervalJob(IntervalJob), GenericJob(GenericJob), FinalizationRegistryCleanupJob(NativeAsyncJob), }
A job that needs to be handled by a JobExecutor.

Requirements

The specification defines many types of jobs, but all of them must adhere to a set of requirements:

  • At some future point in time, when there is no running execution context and the execution context stack is empty, the implementation must:
    • Perform any host-defined preparation steps.
    • Invoke the Job Abstract Closure.
    • Perform any host-defined cleanup steps, after which the execution context stack must be empty.
  • Only one Job may be actively undergoing evaluation at any point in time.
  • Once evaluation of a Job starts, it must run to completion before evaluation of any other Job starts.
  • The Abstract Closure must return a normal completion, implementing its own handling of errors.

Boa is a little bit flexible on the last requirement, since it allows jobs to return either values or errors, but the rest of the requirements must be followed for all conformant implementations.

Additionally, each job type can have additional requirements that must also be followed in addition to the previous ones.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


PromiseJob(PromiseJob)

A Promise-related job.

See PromiseJob for more information.



AsyncJob(NativeAsyncJob)

A Future-related job.

See NativeAsyncJob for more information.



TimeoutJob(TimeoutJob)

A generic job that is to be executed after a number of milliseconds.

See TimeoutJob for more information.



IntervalJob(IntervalJob)

A generic job that is to be executed after intervals of a number of milliseconds.

See TimeoutJob for more information.



GenericJob(GenericJob)

A generic job.

See GenericJob for more information.



FinalizationRegistryCleanupJob(NativeAsyncJob)

A job that will eventually cleanup a FinalizationRegistry.

This job differs slightly from the spec; originally it’s defined as being enqueued exactly when a FinalizationRegistry needs to call FinalizationRegistry::cleanup, but here it’s defined as an async job that suspends execution until it receives a signal from the engine that the FinalizationRegistry needs to be cleaned up.

Execution

As described on the spec’s section about execution,

Because calling HostEnqueueFinalizationRegistryCleanupJob is optional, registered objects in a FinalizationRegistry do not necessarily hold that FinalizationRegistry live. Implementations may omit FinalizationRegistry callbacks for any reason, e.g., if the FinalizationRegistry itself becomes dead, or if the application is shutting down.

For this reason, it is recommended to exclude FinalizationRegistry cleanup jobs from any condition that exits from JobExecutor::run_jobs.

By the same token, it is recommended to execute FinalizationRegistry cleanup jobs separately from all other enqueued NativeAsyncJobs, prioritizing the execution of all other jobs if possible.