Module embedded

Module embedded 

Embedded module loader. Creates a ModuleLoader instance that contains files embedded in the binary at build time.

Macros

embed_module
Create a module loader that embeds files from the filesystem at build time. This is useful for bundling assets with the binary.

Structs

EmbeddedModuleLoader
The resulting type of creating an embedded module loader.

Enums

CompressType
The type of compression used, if any.