pub struct NativeFunction { /* private fields */ }Expand description
A callable Rust function that can be invoked by the engine.
NativeFunction functions are divided in two:
- Function pointers a.k.a common functions (see
NativeFunctionPointer). - Closure functions that can capture the current environment.
Caveats
By limitations of the Rust language, the garbage collector currently cannot inspect closures
in order to trace their captured variables. This means that only Copy closures are 100% safe
to use. All other closures can also be stored in a NativeFunction, albeit by using an unsafe
API, but note that passing closures implicitly capturing traceable types could cause
Undefined Behaviour.
Implementations
Sourceimpl NativeFunction
impl NativeFunction
Sourcepub fn from_fn_ptr(function: NativeFunctionPointer) -> Self
pub fn from_fn_ptr(function: NativeFunctionPointer) -> Self
Creates a NativeFunction from a function pointer.
Sourcepub fn from_async_fn<F>(f: F) -> Self
pub fn from_async_fn<F>(f: F) -> Self
Creates a NativeFunction from a function returning a Future-like.
The returned NativeFunction will return an ECMAScript Promise that will be fulfilled
or rejected when the returned Future completes.
If you only need to convert a Future-like into a JsPromise, see
JsPromise::from_async_fn.
Examples
async fn test(
_this: &JsValue,
args: &[JsValue],
context: &RefCell<&mut Context>,
) -> JsResult<JsValue> {
let arg = args.get_or_undefined(0).clone();
std::future::ready(()).await;
let value = arg.to_u32(&mut context.borrow_mut())?;
Ok(JsValue::from(value * 2))
}
NativeFunction::from_async_fn(test);Sourcepub fn from_copy_closure<F>(closure: F) -> Self
pub fn from_copy_closure<F>(closure: F) -> Self
Creates a NativeFunction from a Copy closure.
Sourcepub fn from_copy_closure_with_captures<F, T>(closure: F, captures: T) -> Self
pub fn from_copy_closure_with_captures<F, T>(closure: F, captures: T) -> Self
Creates a NativeFunction from a Copy closure and a list of traceable captures.
Sourcepub unsafe fn from_closure<F>(closure: F) -> Self
pub unsafe fn from_closure<F>(closure: F) -> Self
Creates a new NativeFunction from a closure.
Safety
Passing a closure that contains a captured variable that needs to be traced by the garbage collector could cause an use after free, memory corruption or other kinds of Undefined Behaviour. See https://github.com/Manishearth/rust-gc/issues/50 for a technical explanation on why that is the case.
Sourcepub unsafe fn from_closure_with_captures<F, T>(closure: F, captures: T) -> Self
pub unsafe fn from_closure_with_captures<F, T>(closure: F, captures: T) -> Self
Create a new NativeFunction from a closure and a list of traceable captures.
Safety
Passing a closure that contains a captured variable that needs to be traced by the garbage collector could cause an use after free, memory corruption or other kinds of Undefined Behaviour. See https://github.com/Manishearth/rust-gc/issues/50 for a technical explanation on why that is the case.
Sourcepub fn call(
&self,
this: &JsValue,
args: &[JsValue],
context: &mut Context,
) -> JsResult<JsValue>
pub fn call( &self, this: &JsValue, args: &[JsValue], context: &mut Context, ) -> JsResult<JsValue>
Calls this NativeFunction, forwarding the arguments to the corresponding function.
Sourcepub fn to_js_function(self, realm: &Realm) -> JsFunction
pub fn to_js_function(self, realm: &Realm) -> JsFunction
Converts this NativeFunction into a JsFunction without setting its name or length.
Useful to create functions that will only be used once, such as callbacks.