TypedJsFunction

Struct TypedJsFunction 

pub struct TypedJsFunction<A: TryIntoJsArguments, R: TryFromJs> { /* private fields */ }
A JavaScript Function rust object, typed. This adds types to a JavaScript exported function, allowing for type checking and type conversion in Rust. Those types must convert to a JsValue but will not be verified at runtime (since JavaScript doesn’t actually have strong typing).

To create this type, use the JsFunction::typed method.

Implementations

Source

impl<A: TryIntoJsArguments, R: TryFromJs> TypedJsFunction<A, R>

pub fn into_inner(self) -> JsFunction

Transforms this typed function back into a regular JsFunction.

pub fn as_js_function(&self) -> &JsFunction

Get the inner JsFunction without consuming this object.

pub fn call(&self, context: &mut Context, args: A) -> JsResult<R>

Call the function with the given arguments.

pub fn call_with_this( &self, this: &JsValue, context: &mut Context, args: A, ) -> JsResult<R>

Call the function with the given argument and this.