TryIntoJsArguments

Trait TryIntoJsArguments 

pub trait TryIntoJsArguments {
    // Required method
    fn into_js_args(self, cx: &mut Context) -> JsResult<Vec<JsValue>>;
}
A trait for converting a tuple of Rust values into a vector of JsValue, to be used as arguments for a JavaScript function.

Required Methods

fn into_js_args(self, cx: &mut Context) -> JsResult<Vec<JsValue>>

Convert a tuple of Rust values into a vector of JsValue. This is automatically implemented for tuples that implement TryIntoJsResult.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<A, B, C, D, E> TryIntoJsArguments for (A, B, C, D, E)

Source

impl<A, B, C, D> TryIntoJsArguments for (A, B, C, D)

Source

impl<A, B, C> TryIntoJsArguments for (A, B, C)

Source

impl<A, B> TryIntoJsArguments for (A, B)

Source

impl<A> TryIntoJsArguments for (A,)
where A: TryIntoJsResult,

Implementors