pub struct ArrayDecl { /* private fields */ }Expand description
An array is an ordered collection of data (either primitive or object depending upon the language).
Arrays are used to store multiple values in a single variable. This is compared to a variable that can store only one value.
Each item in an array has a number attached to it, called a numeric index, that allows you to access it. In JavaScript, arrays start at index zero and can be manipulated with various methods.
More information: