#[non_exhaustive]pub enum Job {
PromiseJob(PromiseJob),
AsyncJob(NativeAsyncJob),
TimeoutJob(TimeoutJob),
GenericJob(GenericJob),
}Expand description
A job that needs to be handled by a JobExecutor.
Requirements
The specification defines many types of jobs, but all of them must adhere to a set of requirements:
- At some future point in time, when there is no running execution context and the execution
context stack is empty, the implementation must:
- Perform any host-defined preparation steps.
- Invoke the Job Abstract Closure.
- Perform any host-defined cleanup steps, after which the execution context stack must be empty.
- Only one Job may be actively undergoing evaluation at any point in time.
- Once evaluation of a Job starts, it must run to completion before evaluation of any other Job starts.
- The Abstract Closure must return a normal completion, implementing its own handling of errors.
Boa is a little bit flexible on the last requirement, since it allows jobs to return either values or errors, but the rest of the requirements must be followed for all conformant implementations.
Additionally, each job type can have additional requirements that must also be followed in addition to the previous ones.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
PromiseJob(PromiseJob)
A Promise-related job.
See PromiseJob for more information.
AsyncJob(NativeAsyncJob)
A Future-related job.
See NativeAsyncJob for more information.
TimeoutJob(TimeoutJob)
A generic job that is to be executed after a number of milliseconds.
See TimeoutJob for more information.
GenericJob(GenericJob)
A generic job.
See GenericJob for more information.