pub struct Object<T: ?Sized> { /* private fields */ }Expand description
The internal representation of a JavaScript object.
Implementations
Sourceimpl<T: ?Sized> Object<T>
impl<T: ?Sized> Object<T>
Sourcepub fn prototype(&self) -> JsPrototype
pub fn prototype(&self) -> JsPrototype
Gets the prototype instance of this object.
Sourcepub fn set_prototype<O: Into<JsPrototype>>(&mut self, prototype: O) -> bool
pub fn set_prototype<O: Into<JsPrototype>>(&mut self, prototype: O) -> bool
Sets the prototype instance of the object.
Sourcepub const fn properties(&self) -> &PropertyMap
pub const fn properties(&self) -> &PropertyMap
Returns the properties of the object.
Sourceimpl Object<dyn NativeObject>
impl Object<dyn NativeObject>
Sourcepub fn is<T: NativeObject>(&self) -> bool
pub fn is<T: NativeObject>(&self) -> bool
Return true if it is a native object and the native type is T.
Sourcepub fn downcast_ref<T: NativeObject>(&self) -> Option<&T>
pub fn downcast_ref<T: NativeObject>(&self) -> Option<&T>
Downcast a reference to the object,
if the object is type native object type T.
Sourcepub fn downcast_mut<T: NativeObject>(&mut self) -> Option<&mut T>
pub fn downcast_mut<T: NativeObject>(&mut self) -> Option<&mut T>
Downcast a mutable reference to the object,
if the object is type native object type T.
Sourcepub fn is_typed_uint8_array(&self) -> bool
pub fn is_typed_uint8_array(&self) -> bool
Checks if it a Uint8Array object.
Sourcepub fn is_typed_int8_array(&self) -> bool
pub fn is_typed_int8_array(&self) -> bool
Checks if it a Int8Array object.
Sourcepub fn is_typed_uint16_array(&self) -> bool
pub fn is_typed_uint16_array(&self) -> bool
Checks if it a Uint16Array object.
Sourcepub fn is_typed_int16_array(&self) -> bool
pub fn is_typed_int16_array(&self) -> bool
Checks if it a Int16Array object.
Sourcepub fn is_typed_uint32_array(&self) -> bool
pub fn is_typed_uint32_array(&self) -> bool
Checks if it a Uint32Array object.
Sourcepub fn is_typed_int32_array(&self) -> bool
pub fn is_typed_int32_array(&self) -> bool
Checks if it a Int32Array object.
Sourcepub fn is_typed_float32_array(&self) -> bool
pub fn is_typed_float32_array(&self) -> bool
Checks if it a Float32Array object.
Sourcepub fn is_typed_float64_array(&self) -> bool
pub fn is_typed_float64_array(&self) -> bool
Checks if it a Float64Array object.